==> php-async-aws-sqs_1.7.0.orig.tar.xz: php-async-aws-sqs-1.7.0/src/ValueObject/ChangeMessageVisibilityBatchRequestEntry.php <==
<?php

namespace AsyncAws\Sqs\ValueObject;

use AsyncAws\Core\Exception\InvalidArgument;

/**
 * Encloses a receipt handle and an entry id for each message in `ChangeMessageVisibilityBatch.`.
 *
 * ! All of the following list parameters must be prefixed with `ChangeMessageVisibilityBatchRequestEntry.n`, where `n`
 * ! is an integer value starting with `1`. For example, a parameter list for this action might look like this:
 *
 * `&amp;ChangeMessageVisibilityBatchRequestEntry.1.Id=change_visibility_msg_2`
 * `&amp;ChangeMessageVisibilityBatchRequestEntry.1.ReceiptHandle=your_receipt_handle`
 * `&amp;ChangeMessageVisibilityBatchRequestEntry.1.VisibilityTimeout=45`
 */
final class ChangeMessageVisibilityBatchRequestEntry
{
    /**
     * An identifier for this particular receipt handle used to communicate the result.
     */
    private $id;

    /**
     * A receipt handle.
     */
    private $receiptHandle;

    /**
     * The new value (in seconds) for the message's visibility timeout.
     */
    private $visibilityTimeout;

    /**
     * @param array{
     *   Id: string,
     *   ReceiptHandle: string,
     *   VisibilityTimeout?: null|int,
     * } $input
     */
    public function __construct(array $input)
    {
        $this->id = $input['Id'] ?? null;
        $this->receiptHandle = $input['ReceiptHandle'] ?? null;
        $this->visibilityTimeout = $input['VisibilityTimeout'] ?? null;
    }

    public static function create($input): self
    {
        return $input instanceof self ? $input : new self($input);
    }

    public function getId(): string
    {
        return $this->id;
    }

    public function getReceiptHandle(): string
    {
        return $this->receiptHandle;
    }

    public function getVisibilityTimeout(): ?int
    {
        return $this->visibilityTimeout;
    }

    /**
     * @internal
     */
    public function requestBody(): array
    {
        $payload = [];
        if (null === $v = $this->id) {
            throw new InvalidArgument(sprintf('Missing parameter "Id" for "%s". The value cannot be null.', __CLASS__));
        }
        $payload['Id'] = $v;
        if (null === $v = $this->receiptHandle) {
            throw new InvalidArgument(sprintf('Missing parameter "ReceiptHandle" for "%s". The value cannot be null.', __CLASS__));
        }
        $payload['ReceiptHandle'] = $v;
        if (null !== $v = $this->visibilityTimeout) {
            $payload['VisibilityTimeout'] = $v;
        }

        return $payload;
    }
}

==> php-async-aws-sqs_2.0.0.orig.tar.xz: php-async-aws-sqs-2.0.0/src/ValueObject/ChangeMessageVisibilityBatchRequestEntry.php <==
<?php

namespace AsyncAws\Sqs\ValueObject;

use AsyncAws\Core\Exception\InvalidArgument;

/**
 * Encloses a receipt handle and an entry ID for each message in `ChangeMessageVisibilityBatch.`.
 */
final class ChangeMessageVisibilityBatchRequestEntry
{
    /**
     * An identifier for this particular receipt handle used to communicate the result.
     *
     * > The `Id`s of a batch request need to be unique within a request.
     * >
     * > This identifier can have up to 80 characters. The following characters are accepted: alphanumeric characters,
     * > hyphens(-), and underscores (_).
     *
     * @var string
     */
    private $id;

    /**
     * A receipt handle.
     *
     * @var string
     */
    private $receiptHandle;

    /**
     * The new value (in seconds) for the message's visibility timeout.
     *
     * @var int|null
     */
    private $visibilityTimeout;

    /**
     * @param array{
     *   Id: string,
     *   ReceiptHandle: string,
     *   VisibilityTimeout?: null|int,
     * } $input
     */
    public function __construct(array $input)
    {
        $this->id = $input['Id'] ?? $this->throwException(new InvalidArgument('Missing required field "Id".'));
        $this->receiptHandle = $input['ReceiptHandle'] ?? $this->throwException(new InvalidArgument('Missing required field "ReceiptHandle".'));
        $this->visibilityTimeout = $input['VisibilityTimeout'] ?? null;
    }

    /**
     * @param array{
     *   Id: string,
     *   ReceiptHandle: string,
     *   VisibilityTimeout?: null|int,
     * }|ChangeMessageVisibilityBatchRequestEntry $input
     */
    public static function create($input): self
    {
        return $input instanceof self ? $input : new self($input);
    }

    public function getId(): string
    {
        return $this->id;
    }

    public function getReceiptHandle(): string
    {
        return $this->receiptHandle;
    }

    public function getVisibilityTimeout(): ?int
    {
        return $this->visibilityTimeout;
    }

    /**
     * @internal
     */
    public function requestBody(): array
    {
        $payload = [];
        $v = $this->id;
        $payload['Id'] = $v;
        $v = $this->receiptHandle;
        $payload['ReceiptHandle'] = $v;
        if (null !== $v = $this->visibilityTimeout) {
            $payload['VisibilityTimeout'] = $v;
        }

        return $payload;
    }

    /**
     * @return never
     */
    private function throwException(\Throwable $exception)
    {
        throw $exception;
    }
}
